@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -22,11 +22,11 @@ class SplashScreenLogHandler(Handler):
 
         Parameters
         ----------
-        splash_screen : ISplashScreen instance
+        splash_screen : ISplashScreen
             The splash screen being used to display the log messages
         """
         # Base class constructor.
-        super(SplashScreenLogHandler, self).__init__()
+        super().__init__()
 
         # The splash screen that we will display log messages on.
         self._splash_screen = splash_screen
@@ -36,7 +36,7 @@ class SplashScreenLogHandler(Handler):
 
         Parameters
         ----------
-        record : logging record instance
+        record : logging record
             The log record to be displayed.
         """
         self._splash_screen.text = str(record.getMessage()) + "..."
