@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,12 +11,9 @@
 import logging
 
 
-from pyface.action.api import MenuBarManager, StatusBarManager, ToolBarManager
-from pyface.api import ApplicationWindow
 from traits.api import (
     Bool,
     Callable,
-    HasTraits,
     HasStrictTraits,
     Instance,
     List,
@@ -27,13 +24,17 @@ from traits.api import (
 )
 
 
+from pyface.action.i_menu_bar_manager import IMenuBarManager
+from pyface.action.i_status_bar_manager import IStatusBarManager
+from pyface.action.i_tool_bar_manager import IToolBarManager
+from pyface.application_window import ApplicationWindow
 from pyface.tasks.action.task_action_manager_builder import (
     TaskActionManagerBuilder,
 )
 from pyface.tasks.i_dock_pane import IDockPane
 from pyface.tasks.i_task_pane import ITaskPane
+from pyface.tasks.i_task_window_backend import ITaskWindowBackend
 from pyface.tasks.task import Task, TaskLayout
-from pyface.tasks.task_window_backend import TaskWindowBackend
 from pyface.tasks.task_window_layout import TaskWindowLayout
 
 # Logging.
@@ -82,7 +83,7 @@ class TaskWindow(ApplicationWindow):
     _active_state = Instance("pyface.tasks.task_window.TaskState")
     _states = List(Instance("pyface.tasks.task_window.TaskState"))
     _title = Str()
-    _window_backend = Instance(TaskWindowBackend)
+    _window_backend = Instance(ITaskWindowBackend)
 
     # ------------------------------------------------------------------------
     # 'Widget' interface.
@@ -91,15 +92,16 @@ class TaskWindow(ApplicationWindow):
     def destroy(self):
         """ Overridden to ensure that all task panes are cleanly destroyed.
         """
-        # Allow the TaskWindowBackend to clean up first.
-        self._window_backend.destroy()
+        if self.control is not None:
+            # Allow the TaskWindowBackend to clean up first.
+            self._window_backend.destroy()
 
-        # Don't use 'remove_task' here to avoid changing the active state and
-        # thereby removing the window's menus and toolbars. This can lead to
-        # undesirable animations when the window is being closed.
-        for state in self._states:
-            self._destroy_state(state)
-        super(TaskWindow, self).destroy()
+            # Don't use 'remove_task' here to avoid changing the active state and
+            # thereby removing the window's menus and toolbars. This can lead to
+            # undesirable animations when the window is being closed.
+            for state in self._states:
+                self._destroy_state(state)
+        super().destroy()
 
     # ------------------------------------------------------------------------
     # 'Window' interface.
@@ -116,7 +118,7 @@ class TaskWindow(ApplicationWindow):
         if not event.veto:
             # Create the control, if necessary.
             if self.control is None:
-                self._create()
+                self.create()
 
             # Activate a task, if necessary.
             if self._active_state is None and self._states:
@@ -184,7 +186,7 @@ class TaskWindow(ApplicationWindow):
         # Make sure the underlying control has been created, even if it is not
         # yet visible.
         if self.control is None:
-            self._create()
+            self.create()
 
         # Create the central pane.
         state.central_pane = task.create_central_pane()
@@ -403,6 +405,7 @@ class TaskWindow(ApplicationWindow):
     # Trait initializers ---------------------------------------------------
 
     def __window_backend_default(self):
+        from pyface.tasks.task_window_backend import TaskWindowBackend
         return TaskWindowBackend(window=self)
 
     # Trait property getters/setters ---------------------------------------
@@ -417,7 +420,9 @@ class TaskWindow(ApplicationWindow):
 
     # Trait change handlers ------------------------------------------------
 
-    def __active_state_changed(self, state):
+    @observe("_active_state")
+    def _update_traits_given_new_active_state(self, event):
+        state = event.new
         if state is None:
             self.active_task = self.central_pane = None
             self.dock_panes = []
@@ -446,15 +451,29 @@ class TaskState(HasStrictTraits):
         with an attached Task.
     """
 
+    #: The Task that the state comes from.
     task = Instance(Task)
+
+    #: The layout of panes in the TaskWindow.
     layout = Instance(TaskLayout)
+
+    #: Whether the task state has been initialized.
     initialized = Bool(False)
 
+    #: The central pane of the TaskWindow
     central_pane = Instance(ITaskPane)
-    dock_panes = List(IDockPane)
-    menu_bar_manager = Instance(MenuBarManager)
-    status_bar_manager = Instance(StatusBarManager)
-    tool_bar_managers = List(ToolBarManager)
+
+    #: The list of all dock panes.
+    dock_panes = List(Instance(IDockPane))
+
+    #: The TaskWindow's menu bar manager instance.
+    menu_bar_manager = Instance(IMenuBarManager)
+
+    #: The TaskWindow's status bar instance.
+    status_bar_manager = Instance(IStatusBarManager)
+
+    #: The TaskWindow's tool bar instances.
+    tool_bar_managers = List(Instance(IToolBarManager))
 
     def get_dock_pane(self, id):
         """ Returns the dock pane with the specified id, or None if no such dock
