@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -36,7 +36,7 @@ class TraitsTaskPane(TaskPane):
         """
         if self.model:
             return {"object": self.model, "pane": self}
-        return super(TraitsTaskPane, self).trait_context()
+        return super().trait_context()
 
     # ------------------------------------------------------------------------
     # 'ITaskPane' interface.
@@ -52,5 +52,7 @@ class TraitsTaskPane(TaskPane):
     def destroy(self):
         """ Destroy the toolkit-specific control that represents the pane.
         """
-        self.ui.dispose()
+        if self.ui is not None:
+            self.ui.dispose()
+            self.ui = None
         self.control = self.ui = None
