@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -47,7 +47,7 @@ class TestColorDialog(unittest.TestCase, GuiTestAssistant):
     def test_create(self):
         # test that creation and destruction works as expected
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.destroy()
 
@@ -59,7 +59,7 @@ class TestColorDialog(unittest.TestCase, GuiTestAssistant):
     def test_close(self):
         # test that close works
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
         with self.event_loop():
             self.dialog.close()
 
@@ -68,7 +68,7 @@ class TestColorDialog(unittest.TestCase, GuiTestAssistant):
         self.dialog.show_alpha = True
 
         with self.event_loop():
-            self.dialog._create()
+            self.dialog.create()
 
 
 @unittest.skipIf(no_gui_test_assistant, "No GuiTestAssistant")
