@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -491,8 +491,6 @@ class _Tool(HasTraits):
         action = self.item.action
         action_event = ActionEvent()
 
-        is_checkable = action.style == "radio" or action.style == "check"
-
         # Perform the action!
         if self.controller is not None:
             # fixme: There is a difference here between having a controller
@@ -566,7 +564,6 @@ class _PaletteTool(HasTraits):
         # And they never contain shortcuts.
         label = label.replace("&", "")
 
-        image = action.image.create_image()
         path = action.image.absolute_path
         bmp = image_cache.get_bitmap(path)
 
@@ -633,8 +630,6 @@ class _PaletteTool(HasTraits):
         action = self.item.action
         action_event = ActionEvent()
 
-        is_checkable = action.style == "radio" or action.style == "check"
-
         # Perform the action!
         action.checked = self.tool_palette.get_tool_state(self.tool_id) == 1
         action.perform(action_event)
