@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2023 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,10 +11,10 @@
 """ Abstract base class for all viewers. """
 
 
-from pyface.widget import Widget
+from pyface.layout_widget import LayoutWidget
 
 
-class Viewer(Widget):
+class Viewer(LayoutWidget):
     """ Abstract base class for all viewers.
 
     A viewer is a model-based adapter on some underlying toolkit-specific
